/*
 * Copyright (c) 2011-2015 Marcus Wichelmann (http://launchpad.net/~l-admin-3)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

public class Home.Widgets.ShutterButton : Gtk.Stack {
    public signal void move (string direction);
    public signal void stop ();

    private Gtk.Box move_button_group;

    private Gtk.Button button_up;
    private Gtk.Button button_down;
    private Gtk.Button button_stop;

    public ShutterButton () {
        build_ui ();
        connect_signals ();
    }

    private void build_ui () {
        this.transition_type = Gtk.StackTransitionType.CROSSFADE;
        this.transition_duration = 200;

        move_button_group = new Gtk.Box (Gtk.Orientation.HORIZONTAL, 0);
        move_button_group.get_style_context ().add_class (Gtk.STYLE_CLASS_LINKED);

        button_up = new Gtk.Button.from_icon_name ("pan-up-symbolic");
        button_down = new Gtk.Button.from_icon_name ("pan-down-symbolic");

        move_button_group.add (button_up);
        move_button_group.add (button_down);

        button_stop = new Gtk.Button.with_label (_("Stop"));
        button_stop.get_style_context ().add_class (Gtk.STYLE_CLASS_DESTRUCTIVE_ACTION);
        button_stop.hexpand = true;

        this.add_named (move_button_group, "idle");
        this.add_named (button_stop, "moving");
    }

    private void connect_signals () {
        button_up.clicked.connect (() => {
            move ("up");
        });

        button_down.clicked.connect (() => {
            move ("down");
        });

        button_stop.clicked.connect (() => {
            stop ();
        });
    }
}